import React from 'react';
import { usePluginContext } from '../../../context/PluginContext/usePluginContext';
import { useServerContext } from '../../../context/ServerContext/useServerContext';
import './Footer.css';

interface FooterProps {
  appVersion?: string;
}

export const Footer: React.FC<FooterProps> = ({ appVersion = '1.0.0' }) => {
  const { plugins } = usePluginContext();
  const { serverInfo } = useServerContext();

  const getServerTypeText = () => {
    if (!serverInfo) return 'No server selected';

    let text = `${serverInfo.server_type}`;
    if (serverInfo.minecraft_version) {
      text += ` (${serverInfo.minecraft_version})`;
    }
    return text;
  };

  return (
    <footer className="footer">
      <div className="footer-left">
        <span className="footer-version">PlugSnatcher v{appVersion}</span>
      </div>


      <div className="footer-right">
        <a
          href="https://git.spacetrainclubhouse.com/Space-Train-Clubhouse/PlugSnatcher"
          target="_blank"
          rel="noopener noreferrer"
          className="github-link"
        >
          Gitea
        </a>
      </div>
    </footer>
  );
};

export default Footer;