import React from 'react';
import ProgressBar from '../../common/ProgressBar/ProgressBar';
import './ScanProgress.css';

interface ScanProgressProps {
  progress: { current: number; total: number } | null;
}

export const ScanProgress: React.FC<ScanProgressProps> = ({ progress }) => {
  // Add console logging for debugging
  React.useEffect(() => {
    console.log("ScanProgress component received progress:", progress);
  }, [progress]);

  const calculatePercentage = (): number => {
    if (!progress) return 0;
    if (progress.total <= 0) return 0; // Handle case where total is 0 or negative

    // Make sure current is at least 0 to prevent NaN
    const current = Math.max(0, progress.current);
    return Math.min(Math.round((current / progress.total) * 100), 100);
  };

  const percentage = calculatePercentage();

  return (
    <div className="scan-progress">
      <div className="scan-progress-header">
        <span className="scan-progress-title">Scanning for plugins...</span>
        <span className="scan-progress-percentage">{percentage}%</span>
      </div>

      <ProgressBar
        value={percentage}
        color="primary"
        showPercentage={false}
      />

      {progress && (
        <div className="scan-progress-details">
          <span className="scan-progress-count">
            {progress.current} of {progress.total} files processed
          </span>
        </div>
      )}
    </div>
  );
};

export default ScanProgress;