import React from 'react';
import ProgressBar from '../../common/ProgressBar/ProgressBar';
import { DownloadProgress } from '../../../types/events.types';
import './DownloadProgressIndicator.css';

interface DownloadProgressIndicatorProps {
  downloadProgress: DownloadProgress;
}

/**
 * Component that displays the progress of a plugin download
 */
export const DownloadProgressIndicator: React.FC<DownloadProgressIndicatorProps> = ({
  downloadProgress
}) => {
  const { pluginName, version, percentage, status, message } = downloadProgress;

  const getStatusText = () => {
    switch (status) {
      case 'downloading':
        return 'Downloading';
      case 'extracting':
        return 'Extracting';
      case 'installing':
        return 'Installing';
      case 'completed':
        return 'Completed';
      case 'error':
        return 'Error';
      default:
        return 'Processing';
    }
  };

  const getStatusIcon = () => {
    switch (status) {
      case 'downloading':
        return '↓';
      case 'extracting':
        return '📦';
      case 'installing':
        return '⚙️';
      case 'completed':
        return '✓';
      case 'error':
        return '⚠️';
      default:
        return '•';
    }
  };

  const getStatusColor = () => {
    switch (status) {
      case 'completed':
        return 'success';
      case 'error':
        return 'error';
      default:
        return 'primary';
    }
  };

  return (
    <div className={`download-progress-indicator download-status-${status}`}>
      <div className="download-progress-header">
        <div className="download-progress-plugin-info">
          <span className="status-icon">{getStatusIcon()}</span>
          <span className="plugin-name">{pluginName}</span>
          <span className="plugin-version">v{version}</span>
        </div>
        <div className="download-status">
          {getStatusText()}
        </div>
      </div>

      <ProgressBar
        value={percentage}
        color={getStatusColor()}
        showPercentage={true}
      />

      {message && (
        <div className="download-message">
          {message}
        </div>
      )}
    </div>
  );
};

export default DownloadProgressIndicator;