import React from 'react';
import Modal from '../../common/Modal/Modal';
import Button from '../../common/Button/Button';
import './PremiumPluginModal.css';
import { PremiumPluginInfo } from '../../../types/events.types';
import { invoke } from '@tauri-apps/api/core';

interface PremiumPluginModalProps {
  isOpen: boolean;
  onClose: () => void;
  pluginInfo: PremiumPluginInfo;
}

/**
 * Modal that displays information about a premium plugin that requires manual download
 */
export const PremiumPluginModal: React.FC<PremiumPluginModalProps> = ({
  isOpen,
  onClose,
  pluginInfo
}) => {
  const handleOpenUrl = async () => {
    try {
      // Use Tauri invoke to call Rust command to open the URL
      await invoke('plugin:shell|open', { url: pluginInfo.url });
    } catch (error) {
      console.error('Failed to open URL:', error);
      // Fallback to standard window.open if invoke fails
      window.open(pluginInfo.url, '_blank');
    }
  };

  return (
    <Modal
      isOpen={isOpen}
      onClose={onClose}
      title="Premium Plugin"
    >
      <div className="premium-plugin-content">
        <div className="premium-plugin-icon">
          <svg viewBox="0 0 24 24" width="48" height="48" fill="currentColor">
            <path d="M12,17.27L18.18,21L16.54,13.97L22,9.24L14.81,8.62L12,2L9.19,8.62L2,9.24L7.45,13.97L5.82,21L12,17.27Z" />
          </svg>
        </div>

        <div className="premium-plugin-message">
          <h3>Premium Plugin Detected</h3>
          <p>
            <strong>{pluginInfo.name}</strong> (version {pluginInfo.version}) is a premium plugin
            that requires manual download from the official source.
          </p>
          <p>
            Click the button below to visit the plugin's website where you can purchase or
            download the update if you already own it.
          </p>
        </div>

        <div className="premium-plugin-actions">
          <Button
            onClick={onClose}
            variant="outline"
          >
            Cancel
          </Button>
          <Button
            onClick={handleOpenUrl}
            variant="primary"
          >
            Open Download Page
          </Button>
        </div>
      </div>
    </Modal>
  );
};

export default PremiumPluginModal;