import { useContext } from 'react';
import { PluginContext } from './PluginContext';

/**
 * Custom hook for accessing the PluginContext
 *
 * @returns The PluginContext values and methods
 * @throws Error if used outside of a PluginProvider
 */
export const usePluginContext = () => {
  const context = useContext(PluginContext);

  if (!context || Object.keys(context).length === 0) {
    throw new Error('usePluginContext must be used within a PluginProvider');
  }

  return context;
};

export default usePluginContext;