import { useContext } from 'react';
import { ServerContext } from './ServerContext';

/**
 * Custom hook for accessing the ServerContext
 *
 * @returns The ServerContext values and methods
 * @throws Error if used outside of a ServerProvider
 */
export const useServerContext = () => {
  const context = useContext(ServerContext);

  if (!context || Object.keys(context).length === 0) {
    throw new Error('useServerContext must be used within a ServerProvider');
  }

  return context;
};

export default useServerContext;