import { useContext } from 'react';
import { UIContext } from './UIContext';

/**
 * Custom hook for accessing the UIContext
 *
 * @returns The UIContext values and methods
 * @throws Error if used outside of a UIProvider
 */
export const useUIContext = () => {
  const context = useContext(UIContext);

  if (!context || Object.keys(context).length === 0) {
    throw new Error('useUIContext must be used within a UIProvider');
  }

  return context;
};

export default useUIContext;