import { ServerType } from '../types/server.types';

/**
 * Returns an emoji icon representing the server type
 * @param serverType The type of Minecraft server
 * @returns A string emoji representing the server type
 */
export function getServerTypeIcon(serverType: ServerType): string {
  switch (serverType) {
    case 'Paper':
      return '📄';
    case 'Spigot':
      return '🔌';
    case 'Bukkit':
      return '🪣';
    case 'Vanilla':
      return '🧊';
    case 'Forge':
      return '🔨';
    case 'Fabric':
      return '🧵';
    case 'Velocity':
      return '⚡';
    case 'BungeeCord':
      return '🔗';
    case 'Waterfall':
      return '🌊';
    default:
      return '❓';
  }
}

/**
 * Returns a formatted display name for the server type
 * @param serverType The type of Minecraft server
 * @returns A formatted string for display
 */
export function getServerTypeName(serverType: ServerType): string {
  return serverType === 'Unknown' ? 'Unknown Server' : serverType;
}

/**
 * Checks if a plugin is compatible with the current server type
 * @param compatibility Array of compatible server types
 * @param currentServerType The current server type
 * @returns True if compatible, false otherwise
 */
export function isCompatibleWithServer(compatibility: string[] | undefined, currentServerType: ServerType | undefined): boolean {
  if (!compatibility || compatibility.length === 0 || !currentServerType) {
    return false;
  }

  return compatibility.includes(currentServerType);
}